# EditFieldController
#
# Release 0.01 (Sep 01, 2009)
# Release 0.02 (Sep 10, 2009) add role check.
#
# This software is provided as-is. You may use it for commercial or
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2004-2009 Yujiro Araki

package MT::Plugin::EditFieldController;

use strict;
use warnings;
use CGI;
use MT;
use base qw( MT::Plugin );
use MT::Template;

our $VERSION = '0.02';

my $plugin = __PACKAGE__->new ({
    id   => 'editfieldcontroller',
    name => 'EditFieldController',
    description => '<MT_TRANS phrase="EditFieldController.">',
    doc_link => 'http://www.koikikukan.com/archives/2009/09/01-005555.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    l10n_class => 'EditFieldController::L10N',
    blog_config_template => 'blog_config.tmpl',
    settings => new MT::PluginSettings([
        ['no_use_for_superuser', { Default => 1 }],
        ['edit_field_controller_check_data', { Default => 0 }],
        ['edit_field_controller_user_name', { Default => '' }],
        ['edit_field_controller_role_name', { Default => '' }],
        ['edit_field_controller_check_process', { Default => 0 }],
        ['edit_field_controller_title', { Default => 0 }],
        ['edit_field_controller_excerpt', { Default => 0 }],
        ['edit_field_controller_tags', { Default => 0 }],
        ['edit_field_controller_keywords', { Default => 0 }],
        ['edit_field_controller_status', { Default => 0 }],
        ['edit_field_controller_publish_date', { Default => 0 }],
        ['edit_field_controller_basename_key', { Default => 0 }],
        ['edit_field_controller_category', { Default => 0 }],
        ['edit_field_controller_folder', { Default => 0 }],
        ['edit_field_controller_accept', { Default => 0 }],
        ['edit_field_controller_ping_urls', { Default => 0 }],
        ['edit_field_controller_delete', { Default => 0 }],
        ['edit_field_controller_display_option', { Default => 0 }],
    ]),
    version => $VERSION,
});
MT->add_plugin($plugin);

sub instance { $plugin }

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_source.edit_entry' => \&disabled_edit_entry,
            'MT::App::CMS::template_source.edit_page' => \&disabled_edit_entry,
        },
    });
}

sub disabled_edit_entry {
    my ($cb, $app, $template) = @_;

    my $superuser = $plugin->get_config_value('no_use_for_superuser', 'blog:' . $app->blog->id);
    return if $superuser;

    my $user_name = $plugin->get_config_value('edit_field_controller_user_name', 'blog:' . $app->blog->id);
    my $role_name = $plugin->get_config_value('edit_field_controller_role_name', 'blog:' . $app->blog->id);
    my $check_process = $plugin->get_config_value('edit_field_controller_check_process', 'blog:' . $app->blog->id);
    my $author = $app->user;
    my $name = $author->name;

    # get user
    my @names;
    if ($user_name =~ /,/) {
        @names = split(",", $user_name);
    } else {
        push(@names, $user_name);
    }
    my $user_match = 0;
    foreach (@names) {
        if ($_ eq $name) {
            $user_match = 1;
        }
    }

    # get role
    require MT::Association;
    require MT::Role;
    my $blog = $app->blog;
    my @roles = MT::Role->load(undef, {
                              join => MT::Association->join_on('role_id', {
                                  author_id => $author->id,
                                  blog_id => $blog->id
                              }, { unique => 1 })
                          });
    my @plugin_roles;
    if ($role_name =~ /,/) {
        @plugin_roles = split(",", $role_name);
    } else {
        push(@plugin_roles, $role_name);
    }
    my $role_match = 0;
    foreach my $plugin_role (@plugin_roles) {
        foreach my $role (@roles) {
            if ($role->name eq $plugin_role) {
                $role_match = 1;
            }
        }
    }

    # check user and role
    if ($user_match || $role_match) {
        if ($check_process) {
            return;
        }
    } else {
        return;
    }

    my $old;
    my $new;

    # title
    my $title = $plugin->get_config_value('edit_field_controller_title', 'blog:' . $app->blog->id);
    if ($title) {
        $old = <<HERE;
<input name="title" id="title" value="<\$mt:var name="title" escape="html"\$>" maxlength="255" mt:watch-change="1" onkeyup="rebasename(this)" />
HERE
        $old = quotemeta($old);
    }
    if ($title == 1) {
        $$template =~ s/$old//;
    } elsif ($title == 2) {
        $new = <<HERE;
<input name="title" id="title" value="<\$mt:var name="title" escape="html"\$>" maxlength="255" mt:watch-change="1" onkeyup="rebasename(this)" readonly="readonly" />
HERE
        $$template =~ s/$old/$new/;
    } elsif ($title == 3) {
        my $new = <<HERE;
<input name="title" id="title" value="<\$mt:var name="title" escape="html"\$>" maxlength="255" mt:watch-change="1" onkeyup="rebasename(this)" disabled="disabled" />
HERE
        $$template =~ s/$old/$new/;
    } 

    # excerpt
    my $excerpt = $plugin->get_config_value('edit_field_controller_excerpt', 'blog:' . $app->blog->id);
    if ($excerpt) {
        $old = <<HERE;
<textarea name="excerpt" id="excerpt" class="full-width short" cols="" rows="" mt:watch-change="1"><\$mt:var name="excerpt" escape="html"\$></textarea>
HERE
        $old = quotemeta($old);
    }
    if ($excerpt == 1) {
        $old = <<HERE;
            <mtapp:setting
                id="excerpt"
                shown="\$show_field"
                label="\$field_label"
                label_class="top-label"
                help_page="entries"
                help_section="excerpt">
                <textarea name="excerpt" id="excerpt" class="full-width short" cols="" rows="" mt:watch-change="1"><\$mt:var name="excerpt" escape="html"\$></textarea>
            </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    } elsif ($title == 2) {
        $new = <<HERE;
<textarea name="excerpt" id="excerpt" class="full-width short" cols="" rows="" mt:watch-change="1" readonly="readonly"><\$mt:var name="excerpt" escape="html"\$></textarea>
HERE
        $$template =~ s/$old/$new/;
    }

    # keywords
    my $keywords = $plugin->get_config_value('edit_field_controller_keywords', 'blog:' . $app->blog->id);
    if ($keywords) {
        $old = <<HERE;
                <div class="textarea-wrapper">
                    <input name="keywords" id="keywords" class="full-width" value="<\$mt:var name="keywords" escape="html"\$>" mt:watch-change="1" autocomplete="off" />
HERE
        $old = quotemeta($old);
    }
    if ($keywords == 1) {
        $old = <<HERE;
            <mtapp:setting
                id="keywords"
                shown="\$show_field"
                label="\$field_label"
                label_class="top-label"
                help_page="entries"
                help_section="keywords">
                <div class="textarea-wrapper">
                    <input name="keywords" id="keywords" class="full-width" value="<\$mt:var name="keywords" escape="html"\$>" mt:watch-change="1" autocomplete="off" />
                </div>
            </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    } elsif ($keywords == 2) {
        $new = <<HERE;
                <div class="textarea-wrapper" style="background-color:#ddd;border:1px solid #999">
                    <input name="keywords" id="keywords" class="full-width" value="<\$mt:var name="keywords" escape="html"\$>" mt:watch-change="1" autocomplete="off" readonly="readonly" style="background:transparent" />
HERE
        $$template =~ s/$old/$new/;
    } elsif ($title == 3) {
        $new = <<HERE;
                <div class="textarea-wrapper" style="background-color:#ddd;border:1px solid #999">
                    <input name="keywords" id="keywords" class="full-width" value="<\$mt:var name="keywords" escape="html"\$>" mt:watch-change="1" autocomplete="off" readonly="readonly" style="background:transparent" />
HERE
        $$template =~ s/$old/$new/;
    }

    # tags
    my $tags = $plugin->get_config_value('edit_field_controller_tags', 'blog:' . $app->blog->id);
    if ($tags) {
        $old = <<HERE;
                    <div class="textarea-wrapper">
                        <input name="tags" id="tags" class="full-width" value="<\$mt:var name="tags" escape="html"\$>" mt:watch-change="1" autocomplete="off" />
HERE
        $old = quotemeta($old);
    }
    if ($tags == 1) {
        $old = <<HERE;
                <mtapp:setting
                    id="tags"
                    shown="\$show_field"
                    label="<__trans phrase="Tags">"
                    label_class="top-label"
                    hint="\$tags_hint"
                    help_page="entries"
                    help_section="entry_tags">
                    <div class="textarea-wrapper">
                        <input name="tags" id="tags" class="full-width" value="<\$mt:var name="tags" escape="html"\$>" mt:watch-change="1" autocomplete="off" />
                        <input type="hidden" name="_ignore_tags" id="tags-cache" value="<\$mt:var name="tags" escape="html"\$>" />
                    </div>
                    <!-- FIXME - move this styling to the ie hacks css file -->
                    <!--[if lte IE 6.5]><div style="position:relative;"><![endif]-->
                    <div id="tags_completion"></div>
                    <!--[if lte IE 6.5]></div><![endif]-->
                </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    } elsif ($tags == 2) {
        $new = <<HERE;
                    <div class="textarea-wrapper" style="background-color:#ddd;border:1px solid #999">
                        <input name="tags" id="tags" class="full-width" value="<\$mt:var name="tags" escape="html"\$>" mt:watch-change="1" autocomplete="off" readonly="readonly" style="background:transparent" />
HERE
        $$template =~ s/$old/$new/;
    } elsif ($title == 3) {
        $new = <<HERE;
                    <div class="textarea-wrapper" style="background-color:#ddd;border:1px solid #999">
                        <input name="tags" id="tags" class="full-width" value="<\$mt:var name="tags" escape="html"\$>" mt:watch-change="1" autocomplete="off" disabled="disabled" style="background:transparent" />
HERE
        $$template =~ s/$old/$new/;
    }

    # display field button
    my $display_option = $plugin->get_config_value('edit_field_controller_display_option', 'blog:' . $app->blog->id);
    if ($display_option) {
        $old = <<HERE;
<\$mt:setvar name="show_display_options_link" value="1"\$>
HERE
        $old = quotemeta($old);
        $new = <<HERE;
<\$mt:setvar name="show_display_options_link" value="0"\$>
HERE
        $$template =~ s/$old/$new/;
    }

    # status
    my $status = $plugin->get_config_value('edit_field_controller_status', 'blog:' . $app->blog->id);
    if ($status) {
        $old = <<HERE;
<select name="status" id="status" class="full-width" onchange="highlightSwitch(this)">
HERE
        $old = quotemeta($old);
    }
    if ($status == 1) {
        $old = <<HERE;
        <mtapp:setting
            id="status"
            label="<__trans phrase="Status">"
            help_page="entries"
            help_section="status">
            <mt:unless name="sitepath_configured">
                            <input type="hidden" name="status" id="status" value="1" /><span><__trans phrase="Unpublished"></span>&nbsp;<span class="alert-warning-inline"><img src="<\$mt:var name="static_uri"\$>images/status_icons/warning.gif" alt="<__trans phrase="Warning">" width="9" height="9" /> <a href="<\$mt:var name="script_url"\$>?__mode=cfg_archives&amp;id=<\$mt:var name="blog_id"\$>&amp;blog_id=<\$mt:var name="blog_id"\$>"><mt:if name="object_type" eq="entry"><__trans phrase="You must configure this blog before you can publish this entry."><mt:else><__trans phrase="You must configure this blog before you can publish this page."></mt:if></a></span>
            <mt:else>
                <mt:if name="can_publish_post">
                            <select name="status" id="status" class="full-width" onchange="highlightSwitch(this)">
                                <option value="1"<mt:if name="status_draft"> selected="selected"</mt:if>><__trans phrase="Unpublished (Draft)"></option>
                                <option value="2"<mt:if name="status_publish"> selected="selected"</mt:if>><__trans phrase="Published"></option>
                    <mt:if name="status_review">
                                <option value="3" selected="selected"><__trans phrase="Unpublished (Review)"></option>
                    <mt:else name="status_spam">
                                <option value="5" selected="selected"><__trans phrase="Unpublished (Spam)"></option>
                    </mt:if>
                    <mt:if name="new_object">
                                    <option value="4"<mt:if name="status_future"> selected="selected"</mt:if>><__trans phrase="Scheduled"></option>
                    <mt:else>
                        <mt:unless name="status_publish">
                                <option value="4"<mt:if name="status_future"> selected="selected"</mt:if>><__trans phrase="Scheduled"></option>
                        </mt:unless>
                    </mt:if>
                            </select>
                <mt:else>
                    <mt:if name="new_object">
                            <input type="hidden" name="status" id="status" value="1" /><span><__trans phrase="Unpublished"></span>
                    <mt:else>
                        <mt:if name="status_draft">
                            <input type="hidden" name="status" id="status" value="1" /><span><__trans phrase="Unpublished (Draft)"></span>
                        <mt:else name="status_publish">
                            <input type="hidden" name="status" id="status" value="2" /><span><__trans phrase="Published"></span>
                        <mt:else name="status_future">
                            <input type="hidden" name="status" id="status" value="4" /><span><__trans phrase="Scheduled"></span>
                        <mt:else name="status_review">
                            <input type="hidden" name="status" id="status" value="3" /><span><__trans phrase="Unpublished (Review)"></span>
                        <mt:else name="status_spam">
                            <input type="hidden" name="status" id="status" value="5" /><span><__trans phrase="Unpublished (Spam)"></span>
                        </mt:if>
                    </mt:if>
                </mt:if>
            </mt:unless>
            <mt:unless name="new_object">
            <ul>
                <li><__trans phrase="[_1] - Created by [_2]" params="<\$mt:date ts="\$created_on_ts" relative="1" _default="\$created_on_formatted"\$>%%<\$mt:var name="created_by" escape="html" escape="html"\$>"></li>
            <mt:if name="status_publish">
                <li><__trans phrase="[_1] - Published by [_2]" params="<\$MTDate ts="\$authored_on_ts" relative="1" _default="\$authored_on_formatted"\$>%%<\$mt:var name="author_name" escape="html" escape="html"\$>"></li>
            </mt:if>
            <mt:if name="modified_by">
                <li><__trans phrase="[_1] - Edited by [_2]" params="<\$MTDate ts="\$modified_on_ts" relative="1" _default="\$modified_on_formatted"\$>%%<\$mt:var name="modified_by" escape="html" escape="html"\$>"></li>
            </mt:if>
            </ul>
            </mt:unless>
        </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    } elsif ($status == 3) {
        $new = <<HERE;
<select name="status" id="status" class="full-width" onchange="highlightSwitch(this)" disabled="desabled">
HERE
        $$template =~ s/$old/$new/;
    }

    # date time
    my $publish_date = $plugin->get_config_value('edit_field_controller_publish_date', 'blog:' . $app->blog->id);
    if ($publish_date == 1) {
        $old = <<HERE;
        <mtapp:setting
            id="authored_on"
            label="\$authored_on_label"
            help_page="entries"
            help_section="date">
            <span class="date-time-fields<mt:if name="status_future"><mt:if name="can_publish_post"> highlight</mt:if></mt:if>">
                <input id="created-on" class="entry-date" name="authored_on_date" value="<\$mt:var name="authored_on_date" escape="html"\$>" />
                <a href="javascript:void(0);" mt:command="open-calendar-created-on" class="date-picker" title="<__trans phrase="Select entry date">"><span>Choose Date</span></a>
                <input class="entry-time" name="authored_on_time" value="<\$mt:var name="authored_on_time" escape="html"\$>" />
            </span>
        </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    } elsif ($publish_date > 1) {
        $old = <<HERE;
            <span class="date-time-fields<mt:if name="status_future"><mt:if name="can_publish_post"> highlight</mt:if></mt:if>">
                <input id="created-on" class="entry-date" name="authored_on_date" value="<\$mt:var name="authored_on_date" escape="html"\$>" />
                <a href="javascript:void(0);" mt:command="open-calendar-created-on" class="date-picker" title="<__trans phrase="Select entry date">"><span>Choose Date</span></a>
                <input class="entry-time" name="authored_on_time" value="<\$mt:var name="authored_on_time" escape="html"\$>" />
            </span>
HERE
        $old = quotemeta($old);
    }
    if ($publish_date == 2) {
        $new = <<HERE;
            <span class="date-time-fields<mt:if name="status_future"><mt:if name="can_publish_post"> highlight</mt:if></mt:if>">
                <input readonly="readonly" id="created-on" class="entry-date" name="authored_on_date" value="<\$mt:var name="authored_on_date" escape="html"\$>" />
                <a href="javascript:void(0);" class="date-picker" title="<__trans phrase="Select entry date">"><span>Choose Date</span></a>
                <input readonly="readonly" class="entry-time" name="authored_on_time" value="<\$mt:var name="authored_on_time" escape="html"\$>" />
            </span>
HERE
        $$template =~ s/$old/$new/;
    }
    if ($publish_date == 3) {
        $new = <<HERE;
            <span class="date-time-fields<mt:if name="status_future"><mt:if name="can_publish_post"> highlight</mt:if></mt:if>">
                <input disabled="desabled" id="created-on" class="entry-date" name="authored_on_date" value="<\$mt:var name="authored_on_date" escape="html"\$>" />
                <a href="javascript:void(0);" class="date-picker" title="<__trans phrase="Select entry date">"><span>Choose Date</span></a>
                <input disabled="desabled" class="entry-time" name="authored_on_time" value="<\$mt:var name="authored_on_time" escape="html"\$>" />
            </span>
HERE
        $$template =~ s/$old/$new/;
    }

    # basename_key
    my $basename_key = $plugin->get_config_value('edit_field_controller_basename_key', 'blog:' . $app->blog->id);
    if ($basename_key == 1) {
        $old = <<HERE;
        <mtapp:setting
            id="basename"
            label="\$basename_label"
            help_page="entries"
            help_section="basename">
                <input type="hidden" name="basename_old" id="basename_old" value="<\$mt:var name="basename_old" escape="html"\$>" />
                <input type="text" <mt:if name="object_type" eq="entry">disabled="disabled"</mt:if> name="basename" id="basename" value="<\$mt:var name="basename" escape="html"\$>" onchange="setElementValue('basename', dirify(this.value))" />
            <mt:if name="object_type" eq="page">
            <span class="file-extension"><\$mt:var name="file_extension" escape="html"\$></span>
            </mt:if>
            <mt:if name="object_type" eq="entry">
                <mt:if name="can_publish_post">
                <a href="javascript:void(0);" id="basename-lock" title="<__trans phrase="Unlock this entry&rsquo;s output filename for editing">" onclick="return toggleFile()"><span>Unlock</span></a>
                </mt:if>
                <p class="alert-warning-inline" id="basename-warning" style="display: none">
                    <img src="<\$mt:var name="static_uri"\$>images/status_icons/warning.gif" alt="<__trans phrase="Warning">" width="9" height="9" />
                <mt:if name="new_object">
                    <__trans phrase="Warning: If you set the basename manually, it may conflict with another entry.">
                <mt:else>
                    <__trans phrase="Warning: Changing this entry's basename may break inbound links.">
                </mt:if>
                </p>
                <input type="hidden" name="basename_manual" id="basename_manual" value="0" />
            <mt:else>
                <input type="hidden" name="basename_manual" id="basename_manual" value="1" />
            </mt:if>
        </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    }
    if ($basename_key == 3) {
        $old = <<HERE;
<a href="javascript:void(0);" id="basename-lock" title="<__trans phrase="Unlock this entry&rsquo;s output filename for editing">" onclick="return toggleFile()"><span>Unlock</span></a>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    }

    # delete button
    my $delete = $plugin->get_config_value('edit_field_controller_delete', 'blog:' . $app->blog->id);
    if ($delete) {
        $old = <<HERE;
    <button
        mt:command="do-remove-items"
        mt:object-singular="<mt:var name="object_label" lower_case="1" escape="html">"
        mt:object-plural="<mt:var name="object_label_plural" lower_case="1" escape="html">"
        mt:object-type="<mt:var name="object_type" escape="html">" mt:blog-id="<mt:var name="blog_id">"
        type="submit"
        accesskey="x"
        title="<mt:var name="delete_button_title">"
        ><__trans phrase="Delete"></button>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    }

    # comment trackback
    my $accept = $plugin->get_config_value('edit_field_controller_accept', 'blog:' . $app->blog->id);
    if ($accept) {
        $old = <<HERE;
                <li><input type="checkbox" name="allow_comments" id="allow_comments" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <label for="allow_comments"><__trans phrase="Comments"/></label></li>
                <li><input type="checkbox" name="allow_pings" id="allow_pings" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <label for="allow_pings"><__trans phrase="TrackBacks"/></label></li>
HERE
        $old = quotemeta($old);
    }
    if ($accept == 1) {
        $old = <<HERE;
        <mtapp:setting
            id="allow_feedback"
            label="<__trans phrase="Accept">"
            help_page="entries"
            help_section="accept_comments">
            <ul>
                <li><input type="checkbox" name="allow_comments" id="allow_comments" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <label for="allow_comments"><__trans phrase="Comments"/></label></li>
                <li><input type="checkbox" name="allow_pings" id="allow_pings" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <label for="allow_pings"><__trans phrase="TrackBacks"/></label></li>
            </ul>
        </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    } elsif ($accept == 3) {
        $new = <<HERE;
                <li><input type="checkbox" name="allow_comments" id="allow_comments" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" disabled="desabled" /> <label for="allow_comments"><__trans phrase="Comments"/></label></li>
                <li><input type="checkbox" name="allow_pings" id="allow_pings" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" disabled="desabled" /> <label for="allow_pings"><__trans phrase="TrackBacks"/></label></li>
HERE
    $$template =~ s/$old/$new/;
    }

    # ping urls
    my $ping_urls = $plugin->get_config_value('edit_field_controller_ping_urls', 'blog:' . $app->blog->id);
    if ($ping_urls) {
        $old = <<HERE;
                <textarea name="to_ping_urls" id="to_ping_urls" class="full-width short" cols="" rows=""><\$mt:var name="to_ping_urls" escape="html"\$></textarea>
HERE
        $old = quotemeta($old);
    }
    if ($ping_urls == 1) {
        $old = <<HERE;
        <mtapp:setting
            id="ping_urls"
            label="<__trans phrase="Outbound TrackBack URLs">"
            hint="\$ping_urls_hint"
            show_hint="\$show_ping_urls_hint"
            help_page="entries"
            help_section="urls_to_ping">
                <textarea name="to_ping_urls" id="to_ping_urls" class="full-width short" cols="" rows=""><\$mt:var name="to_ping_urls" escape="html"\$></textarea>
        </mtapp:setting>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    } elsif ($ping_urls == 2) {
        $new = <<HERE;
                <textarea name="to_ping_urls" id="to_ping_urls" class="full-width short" cols="" rows="" readonly="readonly"><\$mt:var name="to_ping_urls" escape="html"\$></textarea>
HERE
        $$template =~ s/$old/$new/;
    }

    # category
    my $category = $plugin->get_config_value('edit_field_controller_category', 'blog:' . $app->blog->id);
    if ($category) {
        $old = <<HERE;
<div id="category-field"<mt:unless name="disp_prefs_show_category"> class="hidden"</mt:unless>>
    <mt:if name="object_type" eq="entry">
        <mt:setvarblock name="header_action">
            <a href="javascript:void(0)" class="add-new-category-link" id="open-category-selector1" mt:command="open-category-selector" mt:close-el="close-category-selector1" title="<__trans phrase="Add category">"><__trans phrase="edit"/></a>
            <a href="javascript:void(0)" class="add-category-toggle-link hidden" mt:command="close-category-selector" id="close-category-selector1"><__trans phrase="close"></a>
        </mt:setvarblock>
        <mtapp:widget
            id="entry-category-widget"
            label="<__trans phrase="Categories">"
            header_action="\$header_action">
            <\$mt:var name="category_setting"\$>
        </mtapp:widget>
    </mt:if>
</div>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    }

    # folder
    my $folder = $plugin->get_config_value('edit_field_controller_folder', 'blog:' . $app->blog->id);
    if ($folder) {
        $old = <<HERE;
        <mt:if name="object_type" eq="page">
            <\$mt:var name="category_setting"\$>
        </mt:if>
HERE
        $old = quotemeta($old);
        $$template =~ s/$old//;
    }


}

1;
